@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #ifndef _GSM_DEFAULT_TABLE_H_
 #define _GSM_DEFAULT_TABLE_H_
 
@@ -13,9 +12,9 @@ struct PrettyTableItem
   Glib::RefPtr<Glib::Regex> command;
   std::string icon;
 
-  PrettyTableItem(const std::string&a_command,
-                  const std::string&a_icon)
-    : command (Glib::Regex::create ("^(" + a_command + ")$")),
+  PrettyTableItem (const std::string &a_command,
+                   const std::string &a_icon)
+    : command (Glib::Regex::create (("^(" + a_command + ")$").c_str ())),
     icon (a_icon)
   {
   }
